==========================
django-url2png v |version|
==========================

About
=====

Django url2png makes it easy to use the url2png_ service to make web screen shots.

.. _url2png: http://url2png.com


Contents
========

.. toctree::
   :maxdepth: 2
   :glob:

   getting_started
   reference/index
